---
title: <span class="badge object-type-scalar"></span> Millimeter
---
# <span class="badge object-type-scalar"></span> Millimeter

Length: millimeter (mm)

## Definition

```python
# Length: millimeter (mm)
Millimeter: typing.Literal["lengthmm"] = "lengthmm"
```
